@@ -23,7 +23,7 @@
 #include "kbookmarkaction.h"
 #include "kbookmarkcontextmenu.h"
 
-#include <QtCore/QDebug>
+#include "kbookmarks_debug.h"
 #include <QMenu>
 #include <QFile>
 
@@ -57,20 +57,20 @@ void KonqBookmarkContextMenu::addActions()
 
         if (filteredToolbar) {
             QString text = bookmark().showInToolbar() ? tr("Hide in toolbar") : tr("Show in toolbar");
-            addAction(QIcon::fromTheme(QLatin1String("")), text, this, SLOT(toggleShowInToolbar()));
+            addAction(text, this, &KonqBookmarkContextMenu::toggleShowInToolbar);
         }
 
         addFolderActions();
     } else {
         if (owner()) {
-            addAction(QIcon::fromTheme(QStringLiteral("window-new")), tr("Open in New Window"), this, SLOT(openInNewWindow()));
-            addAction(QIcon::fromTheme(QStringLiteral("tab-new")), tr("Open in New Tab"), this, SLOT(openInNewTab()));
+            addAction(QIcon::fromTheme(QStringLiteral("window-new")), tr("Open in New Window"), this, &KonqBookmarkContextMenu::openInNewWindow);
+            addAction(QIcon::fromTheme(QStringLiteral("tab-new")), tr("Open in New Tab"), this, &KonqBookmarkContextMenu::openInNewTab);
         }
         addBookmark();
 
         if (filteredToolbar) {
             QString text = bookmark().showInToolbar() ? tr("Hide in toolbar") : tr("Show in toolbar");
-            addAction(QIcon::fromTheme(QLatin1String("")), text, this, SLOT(toggleShowInToolbar()));
+            addAction(text, this, &KonqBookmarkContextMenu::toggleShowInToolbar);
         }
 
         addBookmarkActions();
@@ -147,7 +147,7 @@ void KonqBookmarkMenu::refill()
 QAction *KonqBookmarkMenu::actionForBookmark(const KBookmark &bm)
 {
     if (bm.isGroup()) {
-        // qDebug() << "Creating Konq bookmark submenu named " << bm.text();
+        // qCDebug(KBOOKMARKS_LOG) << "Creating Konq bookmark submenu named " << bm.text();
         KBookmarkActionMenu *actionMenu = new KBookmarkActionMenu(bm, this);
         m_actionCollection->addAction(QStringLiteral("kbookmarkmenu"), actionMenu);
         m_actions.append(actionMenu);
@@ -159,7 +159,7 @@ QAction *KonqBookmarkMenu::actionForBookmark(const KBookmark &bm)
     } else if (bm.isSeparator()) {
         return KBookmarkMenu::actionForBookmark(bm);
     } else {
-        // qDebug() << "Creating Konq bookmark action named " << bm.text();
+        // qCDebug(KBOOKMARKS_LOG) << "Creating Konq bookmark action named " << bm.text();
         KBookmarkAction *action = new KBookmarkAction(bm, owner(), this);
         m_actionCollection->addAction(action->objectName(), action);
         m_actions.append(action);
@@ -174,7 +174,7 @@ KonqBookmarkMenu::DynMenuInfo KonqBookmarkMenu::showDynamicBookmarks(const QStri
 
     DynMenuInfo info;
     info.show = false;
-    info.d = Q_NULLPTR;
+    info.d = nullptr;
 
     if (!config.hasKey("DynamicMenus")) {
         if (bookmarkrc.hasGroup("DynamicMenu-" + id)) {
@@ -230,7 +230,7 @@ QMenu *KonqBookmarkMenu::contextMenu(QAction *action)
 {
     KBookmarkActionInterface *act = dynamic_cast<KBookmarkActionInterface *>(action);
     if (!act) {
-        return 0;
+        return nullptr;
     }
     return new KonqBookmarkContextMenu(act->bookmark(), manager(), owner());
 }
